Crate renegade_sdk

Crate renegade_sdk 

A Rust SDK for interacting with the Renegade relayer

Modules

api_types
Types for the external match client
types
Types for the Renegade SDK

Structs

AssembleQuoteOptions
The options for assembling a quote
ExternalMatchClient
A client for requesting external matches from the relayer
ExternalMatchOptionsDeprecated
The options for requesting an external match
ExternalOrderBuilder
A builder for an ExternalOrder
RequestQuoteOptions
The options for requesting a quote

Enums

ExternalMatchClientError
An error that can occur when requesting an external match

Constants

GAS_REFUND_ADDRESS_QUERY_PARAM
The auth server query param for the gas refund address
GAS_REFUND_NATIVE_ETH_QUERY_PARAM
The auth server query param for refunding gas in terms of native ETH
GAS_SPONSORSHIP_QUERY_PARAM
The auth server query param for requesting gas sponsorship