pub struct OrderBuilder { /* private fields */ }Expand description
Builder for order configuration
Implementations
Sourceimpl OrderBuilder
impl OrderBuilder
Sourcepub fn with_input_mint(
self,
input_mint: &str,
) -> Result<Self, RenegadeClientError>
pub fn with_input_mint( self, input_mint: &str, ) -> Result<Self, RenegadeClientError>
Set the input mint address
Sourcepub fn with_output_mint(
self,
output_mint: &str,
) -> Result<Self, RenegadeClientError>
pub fn with_output_mint( self, output_mint: &str, ) -> Result<Self, RenegadeClientError>
Set the output mint address
Sourcepub fn with_input_amount(self, amount: Amount) -> Self
pub fn with_input_amount(self, amount: Amount) -> Self
Set the order input token amount
Sourcepub fn with_min_output_amount(self, amount: Amount) -> Self
pub fn with_min_output_amount(self, amount: Amount) -> Self
Set the minimum output token amount that must be received from the order.
This is used to compute a minimum price (in terms of output token per input token) below which fills will not execute.
Sourcepub fn with_min_fill_size(self, min_fill: Amount) -> Self
pub fn with_min_fill_size(self, min_fill: Amount) -> Self
Set the minimum fill size
Sourcepub fn with_allow_external_matches(self, allow: bool) -> Self
pub fn with_allow_external_matches(self, allow: bool) -> Self
Set whether external matches are allowed
Sourcepub fn with_order_type(self, order_type: OrderType) -> Self
pub fn with_order_type(self, order_type: OrderType) -> Self
Set the order type, i.e. which level of privacy to prescribe to it.
Sourcepub fn with_precompute_cancellation_proof(self, precompute: bool) -> Self
pub fn with_precompute_cancellation_proof(self, precompute: bool) -> Self
Set whether to precompute a cancellation proof for the order
Sourcepub fn build(self) -> Result<BuiltOrder, RenegadeClientError>
pub fn build(self) -> Result<BuiltOrder, RenegadeClientError>
Build the order, validating all required fields