pub struct ExternalMatchRequest {
pub do_gas_estimation: bool,
pub receiver_address: Option<String>,
pub external_order: ExternalOrder,
}Expand description
The request type for requesting an external match
Fields
do_gas_estimation: boolWhether or not to include gas estimation in the response
receiver_address: Option<String>The receiver address of the match, if not the message sender
external_order: ExternalOrderThe external order