pub struct ExternalMatchResponseV2 {
pub match_bundle: MalleableAtomicMatchApiBundleV2,
pub gas_sponsorship_info: Option<GasSponsorshipInfo>,
/* private fields */
}Expand description
The response type for requesting a match on an external order
Fields
match_bundle: MalleableAtomicMatchApiBundleV2The match bundle
gas_sponsorship_info: Option<GasSponsorshipInfo>The gas sponsorship info, if the match was sponsored
Implementations
Sourceimpl ExternalMatchResponseV2
impl ExternalMatchResponseV2
Sourcepub fn settlement_tx(&self) -> TransactionRequest
pub fn settlement_tx(&self) -> TransactionRequest
Get a settlement transaction with the current base amount
Sourcepub fn input_bounds(&self) -> (u128, u128)
pub fn input_bounds(&self) -> (u128, u128)
Get the bounds on the input amount
Returns a tuple [min_amount, max_amount] inclusive
Sourcepub fn output_bounds(&self) -> (u128, u128)
pub fn output_bounds(&self) -> (u128, u128)
Get the bounds on the output amount
Returns a tuple [min_amount, max_amount] inclusive
Sourcepub fn receive_amount(&self) -> u128
pub fn receive_amount(&self) -> u128
Get the receive amount at the currently set input amount
Sourcepub fn receive_amount_at_base(&self, input_amount: u128) -> u128
pub fn receive_amount_at_base(&self, input_amount: u128) -> u128
Get the receive amount at the given input amount
Sourcepub fn send_amount(&self) -> u128
pub fn send_amount(&self) -> u128
Get the send amount at the currently set input amount
Sourceimpl ExternalMatchResponseV2
impl ExternalMatchResponseV2
Sourcepub fn set_input_amount(
&mut self,
input_amount: u128,
) -> Result<u128, ExternalMatchClientError>
pub fn set_input_amount( &mut self, input_amount: u128, ) -> Result<u128, ExternalMatchClientError>
Set the input amount of the match_result. Returns the receive amount
(output amount net of fees).
Sourcepub fn set_input_amount_calldata(&mut self, input_amount: u128)
pub fn set_input_amount_calldata(&mut self, input_amount: u128)
Set the calldata to use a given base amount