pub struct FixedPoint {
pub value: BigUint,
}Expand description
A fixed point number
Fields
value: BigUintThe value of the fixed point number
Implementations
Sourceimpl FixedPoint
impl FixedPoint
Sourcepub fn floor_mul_int(&self, amount: Amount) -> Amount
pub fn floor_mul_int(&self, amount: Amount) -> Amount
Multiply a fixed point number by an Amount and return the floor
Sourcepub fn ceil_div_int(amount: Amount, fp: &Self) -> Amount
pub fn ceil_div_int(amount: Amount, fp: &Self) -> Amount
Divide an Amount by a fixed point number and return the ceiling