pub struct GasSponsorshipInfo {
pub refund_amount: u128,
pub refund_native_eth: bool,
pub refund_address: Option<String>,
}Expand description
Metadata regarding gas sponsorship for a quote
Fields
refund_amount: u128The amount to be refunded as a result of gas sponsorship. This amount is firm, it will not change when the quote is assembled.
refund_native_eth: boolWhether the refund is in terms of native ETH.
refund_address: Option<String>The address to which the refund will be sent, if set explicitly.