pub struct MalleableAtomicMatchApiBundleV2 {
pub match_result: ApiBoundedMatchResultV2,
pub fee_rates: FeeTakeRate,
pub max_receive: ApiExternalAssetTransfer,
pub min_receive: ApiExternalAssetTransfer,
pub max_send: ApiExternalAssetTransfer,
pub min_send: ApiExternalAssetTransfer,
pub settlement_tx: TransactionRequest,
pub deadline: u64,
}Expand description
An atomic match settlement bundle using a malleable match result
A malleable match result is one in which the exact input_amount swapped
is not known at the time the proof is generated, and may be changed up until
it is submitted on-chain. Instead, a bounded match result gives a
min_input_amount and a max_input_amount, between which the
input_amount may take any value
Fields
match_result: ApiBoundedMatchResultV2The match result
fee_rates: FeeTakeRateThe fees owed by the external party
max_receive: ApiExternalAssetTransferThe maximum amount that the external party will receive
min_receive: ApiExternalAssetTransferThe minimum amount that the external party will receive
max_send: ApiExternalAssetTransferThe maximum amount that the external party will send
min_send: ApiExternalAssetTransferThe minimum amount that the external party will send
settlement_tx: TransactionRequestThe transaction which settles the match on-chain
deadline: u64The deadline of the bundle, in milliseconds since the epoch