pub struct SignedExternalQuote {
pub quote: ApiExternalQuote,
pub signature: String,
pub gas_sponsorship_info: Option<SignedGasSponsorshipInfo>,
}Expand description
A signed quote for an external order, including gas sponsorship info, if any
Fields
quote: ApiExternalQuoteThe quote
signature: StringThe signature
gas_sponsorship_info: Option<SignedGasSponsorshipInfo>The signed gas sponsorship info, if sponsorship was requested
Implementations
Sourceimpl SignedExternalQuote
impl SignedExternalQuote
Sourcepub fn match_result(&self) -> ApiExternalMatchResult
pub fn match_result(&self) -> ApiExternalMatchResult
Get the match result from the quote
Sourcepub fn receive_amount(&self) -> ApiExternalAssetTransfer
pub fn receive_amount(&self) -> ApiExternalAssetTransfer
Get the receive amount from the quote
Sourcepub fn send_amount(&self) -> ApiExternalAssetTransfer
pub fn send_amount(&self) -> ApiExternalAssetTransfer
Get the send amount from the quote