pub struct SignedExternalQuoteV2 {
pub quote: ApiExternalQuoteV2,
pub signature: String,
pub deadline: u64,
pub gas_sponsorship_info: Option<GasSponsorshipInfo>,
}Expand description
A signed quote for an external order, including gas sponsorship info, if any
Fields
quote: ApiExternalQuoteV2The quote
signature: StringThe signature
deadline: u64The deadline of the quote, in milliseconds since the epoch
gas_sponsorship_info: Option<GasSponsorshipInfo>The signed gas sponsorship info, if sponsorship was requested
Implementations
Sourceimpl SignedExternalQuoteV2
impl SignedExternalQuoteV2
Sourcepub fn from_api_quote(
external_quote: ApiSignedQuoteV2,
gas_sponsorship_info: Option<GasSponsorshipInfo>,
) -> Self
pub fn from_api_quote( external_quote: ApiSignedQuoteV2, gas_sponsorship_info: Option<GasSponsorshipInfo>, ) -> Self
Create a signed quote from an external quote
Sourcepub fn match_result(&self) -> ApiExternalMatchResultV2
pub fn match_result(&self) -> ApiExternalMatchResultV2
Get the match result from the quote
Sourcepub fn receive_amount(&self) -> ApiExternalAssetTransfer
pub fn receive_amount(&self) -> ApiExternalAssetTransfer
Get the receive amount from the quote
Sourcepub fn send_amount(&self) -> ApiExternalAssetTransfer
pub fn send_amount(&self) -> ApiExternalAssetTransfer
Get the send amount from the quote