pub struct RenegadeClientConfig {
pub relayer_base_url: String,
pub historical_state_base_url: String,
pub chain_id: u64,
pub darkpool_address: Address,
pub permit2_address: Address,
pub executor_address: Address,
pub relayer_fee_recipient: Address,
pub key: PrivateKeySigner,
pub admin_hmac_key: Option<HmacKey>,
}Expand description
The client config
Fields
relayer_base_url: StringThe relayer base URL
historical_state_base_url: StringThe historical state base URL
chain_id: u64The chain ID
darkpool_address: AddressThe darkpool contract address
permit2_address: AddressThe permit2 contract address
executor_address: AddressThe relayer’s executor address
relayer_fee_recipient: AddressThe relayer’s fee recipient address
key: PrivateKeySignerThe private key from which to derive the wallet
admin_hmac_key: Option<HmacKey>The HMAC key used to authenticate admin API actions
Implementations
Sourceimpl RenegadeClientConfig
impl RenegadeClientConfig
Sourcepub fn new_arbitrum_one(key: &PrivateKeySigner) -> Self
pub fn new_arbitrum_one(key: &PrivateKeySigner) -> Self
Create a new client config for Arbitrum One
Sourcepub fn new_arbitrum_one_admin(
key: &PrivateKeySigner,
admin_hmac_key: HmacKey,
) -> Self
pub fn new_arbitrum_one_admin( key: &PrivateKeySigner, admin_hmac_key: HmacKey, ) -> Self
Create a new admin client config for Arbitrum One
Sourcepub fn new_arbitrum_sepolia(key: &PrivateKeySigner) -> Self
pub fn new_arbitrum_sepolia(key: &PrivateKeySigner) -> Self
Create a new client config for Arbitrum Sepolia
Sourcepub fn new_arbitrum_sepolia_admin(
key: &PrivateKeySigner,
admin_hmac_key: HmacKey,
) -> Self
pub fn new_arbitrum_sepolia_admin( key: &PrivateKeySigner, admin_hmac_key: HmacKey, ) -> Self
Create a new admin client config for Arbitrum Sepolia
Sourcepub fn new_base_mainnet(key: &PrivateKeySigner) -> Self
pub fn new_base_mainnet(key: &PrivateKeySigner) -> Self
Create a new client config for Base Mainnet
Sourcepub fn new_base_mainnet_admin(
key: &PrivateKeySigner,
admin_hmac_key: HmacKey,
) -> Self
pub fn new_base_mainnet_admin( key: &PrivateKeySigner, admin_hmac_key: HmacKey, ) -> Self
Create a new admin client config for Base Mainnet
Sourcepub fn new_base_sepolia(key: &PrivateKeySigner) -> Self
pub fn new_base_sepolia(key: &PrivateKeySigner) -> Self
Create a new client config for Base Sepolia
Sourcepub fn new_base_sepolia_admin(
key: &PrivateKeySigner,
admin_hmac_key: HmacKey,
) -> Self
pub fn new_base_sepolia_admin( key: &PrivateKeySigner, admin_hmac_key: HmacKey, ) -> Self
Create a new admin client config for Base Sepolia
Sourcepub fn new_ethereum_sepolia(key: &PrivateKeySigner) -> Self
pub fn new_ethereum_sepolia(key: &PrivateKeySigner) -> Self
Create a new client config for Ethereum Sepolia
Sourcepub fn new_ethereum_sepolia_admin(
key: &PrivateKeySigner,
admin_hmac_key: HmacKey,
) -> Self
pub fn new_ethereum_sepolia_admin( key: &PrivateKeySigner, admin_hmac_key: HmacKey, ) -> Self
Create a new admin client config for Ethereum Sepolia