pub enum ExternalMatchClientError {
Http(Option<StatusCode>, String),
InvalidApiKey,
InvalidApiSecret,
InvalidModification(String),
InvalidOrder(String),
Deserialize(String),
}Expand description
An error that can occur when requesting an external match
Variants
Http(Option<StatusCode>, String)
An error that can occur when requesting an external match
InvalidApiKey
An error indicating that the api key is invalid
InvalidApiSecret
An error indicating that the api secret is invalid
InvalidModification(String)
An invalid modification to a malleable match
InvalidOrder(String)
An error indicating that an order is invalid
Deserialize(String)
An error deserializing a response