pub struct AssembleQuoteOptions {
pub do_gas_estimation: bool,
pub allow_shared: bool,
pub receiver_address: Option<String>,
pub updated_order: Option<ExternalOrder>,
}Expand description
The options for assembling a quote (v1 format)
Fields
do_gas_estimation: boolWhether to do gas estimation
Whether or not to allow shared access to the resulting bundle
receiver_address: Option<String>The receiver address that the darkpool will send funds to
If not provided, the receiver address is the message sender
updated_order: Option<ExternalOrder>The updated order to use when assembling the quote
The base_amount, quote_amount, and min_fill_size are allowed to
change, but the pair and side is not
Implementations
Sourceimpl AssembleQuoteOptions
impl AssembleQuoteOptions
Sourcepub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
pub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
Set the gas estimation flag
Set the allow shared flag
Sourcepub fn with_receiver_address(self, receiver_address: String) -> Self
pub fn with_receiver_address(self, receiver_address: String) -> Self
Set the receiver address
Sourcepub fn with_updated_order(self, updated_order: ExternalOrder) -> Self
pub fn with_updated_order(self, updated_order: ExternalOrder) -> Self
Set the updated order