pub struct AssembleQuoteOptionsV2 {
pub do_gas_estimation: bool,
pub receiver_address: Option<String>,
pub updated_order: Option<ExternalOrderV2>,
}Expand description
The options for assembling a v2 quote
Fields
do_gas_estimation: boolWhether to do gas estimation
receiver_address: Option<String>The receiver address that the darkpool will send funds to
If not provided, the receiver address is the message sender
updated_order: Option<ExternalOrderV2>The updated order to use when assembling the quote
The input_amount, output_amount, and min_fill_size are allowed to
change, but the pair is not
Implementations
Sourceimpl AssembleQuoteOptionsV2
impl AssembleQuoteOptionsV2
Sourcepub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
pub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
Set the gas estimation flag
Sourcepub fn with_receiver_address(self, receiver_address: String) -> Self
pub fn with_receiver_address(self, receiver_address: String) -> Self
Set the receiver address
Sourcepub fn with_updated_order(self, updated_order: ExternalOrderV2) -> Self
pub fn with_updated_order(self, updated_order: ExternalOrderV2) -> Self
Set the updated order