pub struct ExternalMatchClient { /* private fields */ }Expand description
A client for requesting external matches from the relayer
Implementations
Sourceimpl ExternalMatchClient
impl ExternalMatchClient
Sourcepub fn new(
api_key: &str,
api_secret: &str,
auth_base_url: &str,
relayer_base_url: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new( api_key: &str, api_secret: &str, auth_base_url: &str, relayer_base_url: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client
Sourcepub fn new_with_client(
api_key: &str,
api_secret: &str,
auth_base_url: &str,
relayer_base_url: &str,
client: Client,
) -> Result<Self, ExternalMatchClientError>
pub fn new_with_client( api_key: &str, api_secret: &str, auth_base_url: &str, relayer_base_url: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>
Create a new client with a custom HTTP client
Sourcepub fn new_ethereum_sepolia_client(
api_key: &str,
api_secret: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new_ethereum_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Ethereum Sepolia network
Sourcepub fn new_ethereum_sepolia_with_client(
api_key: &str,
api_secret: &str,
client: Client,
) -> Result<Self, ExternalMatchClientError>
pub fn new_ethereum_sepolia_with_client( api_key: &str, api_secret: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Ethereum Sepolia network with custom HTTP client
Sourcepub fn new_arbitrum_sepolia_client(
api_key: &str,
api_secret: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new_arbitrum_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Arbitrum Sepolia network
Sourcepub fn new_base_sepolia_client(
api_key: &str,
api_secret: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new_base_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Base Sepolia network
Sourcepub fn new_arbitrum_one_client(
api_key: &str,
api_secret: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new_arbitrum_one_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Arbitrum One network
Sourcepub fn new_arbitrum_one_with_client(
api_key: &str,
api_secret: &str,
client: Client,
) -> Result<Self, ExternalMatchClientError>
pub fn new_arbitrum_one_with_client( api_key: &str, api_secret: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Arbitrum One network with custom HTTP client
Sourcepub fn new_base_mainnet_client(
api_key: &str,
api_secret: &str,
) -> Result<Self, ExternalMatchClientError>
pub fn new_base_mainnet_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Base mainnet network
Sourcepub fn new_base_mainnet_with_client(
api_key: &str,
api_secret: &str,
client: Client,
) -> Result<Self, ExternalMatchClientError>
pub fn new_base_mainnet_with_client( api_key: &str, api_secret: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>
Create a new client for the Base mainnet network with custom HTTP client
Sourcepub async fn get_markets(
&self,
) -> Result<GetMarketsResponse, ExternalMatchClientError>
pub async fn get_markets( &self, ) -> Result<GetMarketsResponse, ExternalMatchClientError>
Get a list of tradable markets. Includes the tokens pair, current price, and fee rates for each market.
Sourcepub async fn get_market_depth(
&self,
address: &str,
) -> Result<GetMarketDepthByMintResponse, ExternalMatchClientError>
pub async fn get_market_depth( &self, address: &str, ) -> Result<GetMarketDepthByMintResponse, ExternalMatchClientError>
Get the market depth for the given token.
The address is the address of the token
Sourcepub async fn get_market_depths_all_pairs(
&self,
) -> Result<GetMarketDepthsResponse, ExternalMatchClientError>
pub async fn get_market_depths_all_pairs( &self, ) -> Result<GetMarketDepthsResponse, ExternalMatchClientError>
Get the market depths for all supported pairs
Sourcepub async fn request_quote_v2(
&self,
order: ExternalOrderV2,
) -> Result<Option<SignedExternalQuoteV2>, ExternalMatchClientError>
pub async fn request_quote_v2( &self, order: ExternalOrderV2, ) -> Result<Option<SignedExternalQuoteV2>, ExternalMatchClientError>
Request a quote for an external match (v2 API)
Sourcepub async fn request_quote_with_options_v2(
&self,
order: ExternalOrderV2,
options: RequestQuoteOptions,
) -> Result<Option<SignedExternalQuoteV2>, ExternalMatchClientError>
pub async fn request_quote_with_options_v2( &self, order: ExternalOrderV2, options: RequestQuoteOptions, ) -> Result<Option<SignedExternalQuoteV2>, ExternalMatchClientError>
Request a quote for an external match, with options (v2 API)
Sourcepub async fn assemble_quote_v2(
&self,
quote: SignedExternalQuoteV2,
) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
pub async fn assemble_quote_v2( &self, quote: SignedExternalQuoteV2, ) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
Assemble a quote into a match bundle, ready for settlement (v2 API)
Sourcepub async fn assemble_quote_with_options_v2(
&self,
quote: SignedExternalQuoteV2,
options: AssembleQuoteOptionsV2,
) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
pub async fn assemble_quote_with_options_v2( &self, quote: SignedExternalQuoteV2, options: AssembleQuoteOptionsV2, ) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
Assemble a quote into a match bundle, ready for settlement, with options (v2 API)
Sourcepub async fn request_external_match_v2(
&self,
order: ExternalOrderV2,
) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
pub async fn request_external_match_v2( &self, order: ExternalOrderV2, ) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
Request an external match (v2 API)
Sourcepub async fn request_external_match_with_options_v2(
&self,
order: ExternalOrderV2,
options: ExternalMatchOptions,
) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
pub async fn request_external_match_with_options_v2( &self, order: ExternalOrderV2, options: ExternalMatchOptions, ) -> Result<Option<ExternalMatchResponseV2>, ExternalMatchClientError>
Request an external match and specify any options for the request (v2 API)
Sourcepub async fn get_exchange_metadata(
&self,
) -> Result<ExchangeMetadataResponse, ExternalMatchClientError>
pub async fn get_exchange_metadata( &self, ) -> Result<ExchangeMetadataResponse, ExternalMatchClientError>
Get metadata about the Renegade exchange
Sourceimpl ExternalMatchClient
impl ExternalMatchClient
Sourcepub async fn get_supported_tokens(
&self,
) -> Result<GetSupportedTokensResponse, ExternalMatchClientError>
👎Deprecated since 2.0.0: Use get_markets instead, which returns all supported tokens along with their current price
pub async fn get_supported_tokens( &self, ) -> Result<GetSupportedTokensResponse, ExternalMatchClientError>
Get a list of supported tokens for external matches
Sourcepub async fn get_token_prices(
&self,
) -> Result<GetTokenPricesResponse, ExternalMatchClientError>
👎Deprecated since 2.0.0: Use get_markets instead, which returns all supported tokens along with their current price
pub async fn get_token_prices( &self, ) -> Result<GetTokenPricesResponse, ExternalMatchClientError>
Get token prices for all supported tokens
Sourcepub async fn get_order_book_depth(
&self,
address: &str,
) -> Result<GetDepthByMintResponse, ExternalMatchClientError>
👎Deprecated since 2.0.0: Use get_market_depth instead
pub async fn get_order_book_depth( &self, address: &str, ) -> Result<GetDepthByMintResponse, ExternalMatchClientError>
Get the order book depth for a token
The address is the address of the token
Sourcepub async fn get_order_book_depth_all_pairs(
&self,
) -> Result<GetDepthForAllPairsResponse, ExternalMatchClientError>
👎Deprecated since 2.0.0: Use get_market_depths_all_pairs instead
pub async fn get_order_book_depth_all_pairs( &self, ) -> Result<GetDepthForAllPairsResponse, ExternalMatchClientError>
Get the order book depth for all supported tokens
Sourcepub async fn request_quote(
&self,
order: ExternalOrder,
) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>
pub async fn request_quote( &self, order: ExternalOrder, ) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>
Request a quote for an external match (v1 API)
Sourcepub async fn request_quote_with_options(
&self,
order: ExternalOrder,
options: RequestQuoteOptions,
) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>
pub async fn request_quote_with_options( &self, order: ExternalOrder, options: RequestQuoteOptions, ) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>
Request a quote for an external match, with options (v1 API)
Sourcepub async fn assemble_quote(
&self,
quote: SignedExternalQuote,
) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
pub async fn assemble_quote( &self, quote: SignedExternalQuote, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
Assemble a quote into a match bundle, ready for settlement (v1 API)
Returns a non-malleable ExternalMatchResponse
Sourcepub async fn assemble_quote_with_options(
&self,
quote: SignedExternalQuote,
options: AssembleQuoteOptions,
) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
pub async fn assemble_quote_with_options( &self, quote: SignedExternalQuote, options: AssembleQuoteOptions, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
Assemble a quote into a match bundle with options (v1 API)
Returns a non-malleable ExternalMatchResponse
Sourcepub async fn request_external_match(
&self,
order: ExternalOrder,
) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
pub async fn request_external_match( &self, order: ExternalOrder, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
Request an external match (v1 API)
Returns a non-malleable ExternalMatchResponse
Sourcepub async fn request_external_match_with_options(
&self,
order: ExternalOrder,
options: ExternalMatchOptions,
) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
pub async fn request_external_match_with_options( &self, order: ExternalOrder, options: ExternalMatchOptions, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>
Request an external match with options (v1 API)
Returns a non-malleable ExternalMatchResponse