pub struct ExternalMatchOptions {
pub do_gas_estimation: bool,
pub sponsor_gas: bool,
pub gas_refund_address: Option<String>,
pub receiver_address: Option<String>,
}Expand description
The options for requesting an external match
Fields
do_gas_estimation: boolWhether to perform gas estimation
sponsor_gas: boolWhether or not to request gas sponsorship for the match
If granted, the auth server will sign the bundle to indicate that the
gas paid to settle the match should be refunded to the given address
(tx.origin if not specified). This is subject to a rate limit.
gas_refund_address: Option<String>The address to refund gas to if sponsor_gas is true
receiver_address: Option<String>The receiver address that the darkpool will send funds to
If not provided, the receiver address is the message sender
Implementations
Sourceimpl ExternalMatchOptions
impl ExternalMatchOptions
Sourcepub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
pub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self
Set the gas estimation flag
Sourcepub fn with_receiver_address(self, receiver_address: String) -> Self
pub fn with_receiver_address(self, receiver_address: String) -> Self
Set the receiver address
Sourcepub fn request_gas_sponsorship(self) -> Self
pub fn request_gas_sponsorship(self) -> Self
Request gas sponsorship
Sourcepub fn with_gas_refund_address(self, gas_refund_address: String) -> Self
pub fn with_gas_refund_address(self, gas_refund_address: String) -> Self
Set the gas refund address