pub struct ExternalOrder {
pub quote_mint: String,
pub base_mint: String,
pub side: OrderSide,
pub base_amount: Amount,
pub quote_amount: Amount,
pub exact_base_output: Amount,
pub exact_quote_output: Amount,
pub min_fill_size: Amount,
}Expand description
An external order (v1 format with base/quote/side)
Fields
quote_mint: StringThe mint (erc20 address) of the quote token
base_mint: StringThe mint (erc20 address) of the base token
side: OrderSideThe side of the market this order is on
base_amount: AmountThe base amount of the order
quote_amount: AmountThe quote amount of the order
exact_base_output: AmountThe exact base amount to output from the order
exact_quote_output: AmountThe exact quote amount to output from the order
min_fill_size: AmountThe minimum fill size for the order