A Rust SDK for interacting with the Renegade relayer
Modules
Structs
- Assemble
Quote Options - The options for assembling a quote
- External
Match Client - A client for requesting external matches from the relayer
- External
Match Options Deprecated - The options for requesting an external match
- External
Order Builder - A builder for an
ExternalOrder - Request
Quote Options - The options for requesting a quote
Enums
- External
Match Client Error - An error that can occur when requesting an external match
Constants
- GAS_
REFUND_ ADDRESS_ QUERY_ PARAM - The auth server query param for the gas refund address
- GAS_
REFUND_ NATIVE_ ETH_ QUERY_ PARAM - The auth server query param for refunding gas in terms of native ETH
- GAS_
SPONSORSHIP_ QUERY_ PARAM - The auth server query param for requesting gas sponsorship