ExternalMatchClient

Struct ExternalMatchClient 

pub struct ExternalMatchClient { /* private fields */ }
A client for requesting external matches from the relayer

Implementations

Source

impl ExternalMatchClient

pub fn new( api_key: &str, api_secret: &str, auth_base_url: &str, relayer_base_url: &str, ) -> Result<Self, ExternalMatchClientError>

Create a new client

pub fn new_with_client( api_key: &str, api_secret: &str, auth_base_url: &str, relayer_base_url: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>

Create a new client with a custom HTTP client

pub fn new_arbitrum_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Arbitrum Sepolia network

pub fn new_base_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Base Sepolia network

pub fn new_sepolia_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

👎Deprecated since 0.1.6: Use new_arbitrum_sepolia_client instead

Create a new client for the Arbitrum Sepolia network

pub fn new_arbitrum_one_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Arbitrum One network

pub fn new_arbitrum_one_with_client( api_key: &str, api_secret: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Arbitrum One network with custom HTTP client

pub fn new_base_mainnet_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Base mainnet network

pub fn new_base_mainnet_with_client( api_key: &str, api_secret: &str, client: Client, ) -> Result<Self, ExternalMatchClientError>

Create a new client for the Base mainnet network with custom HTTP client

pub fn new_mainnet_client( api_key: &str, api_secret: &str, ) -> Result<Self, ExternalMatchClientError>

👎Deprecated since 0.1.6: Use new_arbitrum_one_client instead

Create a new client for the Arbitrum One network

pub async fn get_supported_tokens( &self, ) -> Result<GetSupportedTokensResponse, ExternalMatchClientError>

Get a list of supported tokens for external matches

pub async fn get_token_prices( &self, ) -> Result<GetTokenPricesResponse, ExternalMatchClientError>

Get token prices for all supported tokens

pub async fn get_order_book_depth( &self, address: &str, ) -> Result<GetDepthByMintResponse, ExternalMatchClientError>

Get the order book depth for a token

The address is the address of the token

pub async fn get_order_book_depth_all_pairs( &self, ) -> Result<GetDepthForAllPairsResponse, ExternalMatchClientError>

Get the order book depth for all supported tokens

pub async fn request_quote( &self, order: ExternalOrder, ) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>

Request a quote for an external match

pub async fn request_quote_with_options( &self, order: ExternalOrder, options: RequestQuoteOptions, ) -> Result<Option<SignedExternalQuote>, ExternalMatchClientError>

Request a quote for an external match, with options

pub async fn assemble_quote( &self, quote: SignedExternalQuote, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>

Assemble a quote into a match bundle, ready for settlement

pub async fn assemble_quote_with_options( &self, quote: SignedExternalQuote, options: AssembleQuoteOptions, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>

Assemble a quote into a match bundle, ready for settlement, with options

pub async fn assemble_malleable_quote( &self, quote: SignedExternalQuote, ) -> Result<Option<MalleableExternalMatchResponse>, ExternalMatchClientError>

Assemble a quote into a malleable match bundle, ready for settlement

pub async fn assemble_malleable_quote_with_options( &self, quote: SignedExternalQuote, options: AssembleQuoteOptions, ) -> Result<Option<MalleableExternalMatchResponse>, ExternalMatchClientError>

Assemble a quote into a malleable match bundle, ready for settlement, with options

pub async fn request_external_match( &self, order: ExternalOrder, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>

👎Deprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

Request an external match

pub async fn request_external_match_with_options( &self, order: ExternalOrder, options: ExternalMatchOptions, ) -> Result<Option<ExternalMatchResponse>, ExternalMatchClientError>

👎Deprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

Request an external match and specify any options for the request