ExternalMatchOptions

Struct ExternalMatchOptions 

pub struct ExternalMatchOptions {
    pub do_gas_estimation: bool,
    pub sponsor_gas: bool,
    pub gas_refund_address: Option<String>,
    pub receiver_address: Option<String>,
}
๐Ÿ‘ŽDeprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead
The options for requesting an external match

Fields

do_gas_estimation: bool
๐Ÿ‘ŽDeprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

Whether to perform gas estimation

sponsor_gas: bool
๐Ÿ‘ŽDeprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

Whether or not to request gas sponsorship for the match

If granted, the auth server will sign the bundle to indicate that the gas paid to settle the match should be refunded to the given address (tx.origin if not specified). This is subject to a rate limit.

gas_refund_address: Option<String>
๐Ÿ‘ŽDeprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

The address to refund gas to if sponsor_gas is true

receiver_address: Option<String>
๐Ÿ‘ŽDeprecated since 0.1.0: This endpoint will soon be removed, use request_quote and assemble_quote instead

The receiver address that the darkpool will send funds to

If not provided, the receiver address is the message sender

Implementations

Source

impl ExternalMatchOptions

pub fn new() -> Self

Create a new options with default values

pub fn with_gas_estimation(self, do_gas_estimation: bool) -> Self

Set the gas estimation flag

pub fn with_receiver_address(self, receiver_address: String) -> Self

Set the receiver address

pub fn request_gas_sponsorship(self) -> Self

Request gas sponsorship

pub fn with_gas_refund_address(self, gas_refund_address: String) -> Self

Set the gas refund address