pub struct RequestQuoteOptions {
pub disable_gas_sponsorship: bool,
pub gas_refund_address: Option<String>,
pub refund_native_eth: bool,
}Expand description
The options for requesting a quote
Fields
disable_gas_sponsorship: boolWhether to disable gas sponsorship
gas_refund_address: Option<String>The address to refund gas to if sponsor_gas is true
refund_native_eth: boolWhether to refund gas in terms of native ETH, as opposed to in-kind
Implementations
Sourceimpl RequestQuoteOptions
impl RequestQuoteOptions
Sourcepub fn disable_gas_sponsorship(self) -> Self
pub fn disable_gas_sponsorship(self) -> Self
Disable gas sponsorship
Sourcepub fn with_gas_refund_address(self, gas_refund_address: String) -> Self
pub fn with_gas_refund_address(self, gas_refund_address: String) -> Self
Set the gas refund address
Sourcepub fn with_refund_native_eth(self) -> Self
pub fn with_refund_native_eth(self) -> Self
Set whether to refund gas in terms of native ETH